"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useRect = useRect;

var _react = require("react");

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function getRect(element) {
  var rect = {
    bottom: 0,
    height: 0,
    left: 0,
    right: 0,
    top: 0,
    width: 0
  };
  if (element) rect = element.getBoundingClientRect();
  return rect;
}

function useRect(ref) {
  var _useState = (0, _react.useState)(ref && ref.current ? getRect(ref.current) : getRect()),
      _useState2 = _slicedToArray(_useState, 2),
      rect = _useState2[0],
      setRect = _useState2[1];

  var handleResize = (0, _react.useCallback)(function () {
    if (!ref.current) return;
    setRect(getRect(ref.current)); // Update client rect
  }, [ref]);
  (0, _react.useLayoutEffect)(function () {
    var element = ref.current;
    if (!element) return;
    handleResize(); // @ts-ignore

    if (typeof ResizeObserver === 'function') {
      // @ts-ignore
      var resizeObserver = new ResizeObserver(function () {
        return handleResize();
      });
      resizeObserver.observe(element);
      return function () {
        if (!resizeObserver) return;
        resizeObserver.disconnect(); // @ts-ignore

        resizeObserver = null;
      };
    } else {
      window.addEventListener('resize', handleResize); // Browser support, remove freely

      return function () {
        return window.removeEventListener('resize', handleResize);
      };
    }
  }, [ref.current]);
  return rect;
}